from Products.CMFPlone.utils import log, getToolByName

def marcaComoPaga(self, state_change, **kw):
    obj = state_change.object
    obj.setPaga(True)
    obj.reindexObject()
    template = obj.template_pagamento_realizado
    params = {
        'nome': obj.getNome(),
        'email': obj.getEmail(),
        'URL': obj.absolute_url(),
    }
    _enviaEmail(obj, template(obj), template.title, params)

def enviaEmailConfirmacao(self, state_change, **kw):
    obj = state_change.object
    template = obj.template_inscricao
    params = {
        'nome': obj.getNome(),
        'email': obj.getEmail(),
        'URL': obj.absolute_url(),
    }
    _enviaEmail(obj, template(obj), template.title, params)

def depoisSalvar(self, state_change, **kw):
    obj = state_change.object
    template = obj.template_recebimento_trabalho
    params = {
        'nome': obj.getNome(),
        'email': obj.getEmail(),
        'titulo': obj.Title(),
    }
    _enviaEmail(obj, template(obj), template.title, params)

def depoisAprovar(self, state_change, **kw):
    obj = state_change.object
    template = obj.template_aprovacao_trabalho
    params = {
        'nome': obj.getNome(),
        'email': obj.getEmail(),
        'titulo': obj.Title(),
    }
    _enviaEmail(obj, template(obj), template.title, params)

def depoisRejeitar(self, state_change, **kw):
    obj = state_change.object
    template = obj.template_rejeicao_trabalho
    params = {
        'nome': obj.getNome(),
        'email': obj.getEmail(),
        'titulo': obj.Title(),
    }
    _enviaEmail(obj, template(obj), template.title, params)

def enviaEmailPreInscritos(self, state_change, **kw):
    obj = state_change.object
    template = obj.template_confirmacao
    inscricoes = obj.portal_catalog(portal_type='Inscricao',
                                    review_state='pre-inscrito')
    for inscricao in inscricoes:
        params = {
            'nome': inscricao.getNome,
            'email': inscricao.getEmail,
            'UID': inscricao.UID,
        }
        _enviaEmail(obj, template(obj), template.title, params)

def _enviaEmail(obj, template, subject, params, charset='utf-8'):
    mto = "%s <%s>" % (params['nome'], params['email'])
    mfrom = "%s <%s>" % (obj.email_from_name, obj.email_from_address)
    obj.MailHost.secureSend(template % params, mto, mfrom,
                            subject, charset=charset)



## Script (Python) "segunda_via"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=dados
##title=
##
template = context.template_segunda_via(context)

if not dados:
    dados = {
        'nome': context.getNome(),
        'email': context.getEmail(),
        'URL': context.absolute_url(),
    }

context.MailHost.send(template % dados)

return 'Enviado'



## Script (Python) "aviso_segunda_via"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=path='/pycon/2009/sobre-o-evento/inscricoes/'
##title=
##
response = context.REQUEST.response
response.setHeader('Content-Type', 'text/plain; charset=utf-8')

pendentes = context.portal_catalog(path=path, portal_type='Inscricao',
                                   getPaga=False, sort_on='sortable_title')

for inscricao in pendentes:
    if inscricao.getTipo > '3':
        continue
    dados = {
        'nome': inscricao.getNome,
        'email': inscricao.getEmail,
        'URL': inscricao.getURL(),
    }
    try:
        context.segunda_via(dados=dados)
        response.write('OK: %s\n' % dados['getNome'])
    except:
        response.write('ERRO: %s %s\n' % (dados['URL'], dados['getNome']))




from PIL import Image
from PIL import ImageDraw
from PIL import ImageFont

# Change these values to match your needs
cert_file = '/home/apyb/certificado2009.png'
font_file = '/home/apyb/verdana.ttf'

def generate(name, role):

    img = Image.open(cert_file)
    draw = ImageDraw.Draw(img)

    font = ImageFont.truetype(font_file, 128)

    pos = 1750, 1620
    draw.text(pos, name, font=font)

    pos = 3500 ,2230
    draw.text(pos, role, font=font)

    return img.tostring()

if __name__ == '__main__':
    print generate('Dorneles Tremea', 'participante')
